Name:           bzip3
Version:        1.4.0
Release:    1%{?dist}
Summary:        Tools for compressing and decompressing bzip3 files
License:        LGPL-3.0-or-later AND BSD-2-Clause
SourceLicense:  GPL-3.0-or-later AND GPL-3.0-or-later WITH Autoconf-exception-macro AND GPL-3.0-or-later WITH Autoconf-exception-generic-3.0 AND GPL-2.0-or-later WITH Autoconf-exception-generic AND GPL-2.0-or-later WITH Libtool-exception AND LGPL-3.0-or-later AND BSD-2-Clause AND Apache-2.0 AND MIT AND X11 AND FSFULLR AND FSFUL AND FSFAP
URL:            https://github.com/kspalaiologos/%{name} 
Source0:        %{url}/releases/download/%{version}/%{name}-%{version}.tar.xz 
Patch0:         bzip3-1.2.2-Do-not-use-usr-bin-env-in-shell-bangs.patch
BuildRequires:  autoconf
BuildRequires:  autoconf-archive
BuildRequires:  automake
BuildRequires:  bash
BuildRequires:  coreutils
BuildRequires:  findutils
BuildRequires:  gawk
BuildRequires:  gcc
BuildRequires:  gnulib-devel
BuildRequires:  libtool
BuildRequires:  make
BuildRequires:  pkgconf-pkg-config
BuildRequires:  sed
Requires:       %{name}-libs = %{version}-%{release}
Requires:       grep
Requires:       less
Requires:       util-linux-core
Requires:       most

%description
These are tools for compressing, decompressing, printing, and searching bzip3
files. bzip3 features higher compression ratios and better performance than
bzip2 thanks to an order-0 context mixing entropy coder, a fast
Burrows-Wheeler transform code making use of suffix arrays and a run-length
encoding with Lempel-Ziv prediction pass based on LZ77-style string matching
and PPM-style context modeling.

%package libs
Summary:        Shared libraries for bzip3 compression and decompression
License:        LGPL-3.0-or-later AND Apache-2.0 
Provides:       bundled(libsais) = 2.7.0

%description libs
This is a library for compressing and decompressing bzip3 compression format.
bzip3 features higher compression ratios and better performance than bzip2
thanks to an order-0 context mixing entropy coder, a fast Burrows-Wheeler
transform code making use of suffix arrays and a run-length encoding with
Lempel-Ziv prediction pass based on LZ77-style string matching and PPM-style
context modeling.

%package devel
Summary:        Files for developing with bzip3 library
License:        LGPL-3.0-or-later
Requires:       %{name}-libs = %{version}-%{release}

%description devel
Header files, a pkg-config module and link objects for building applications
which use a bzip3 library.

%prep
%autosetup -p1
rm aclocal.m4 configure Makefile.in
for F in *.1.in; do
    rm "${F%%.in}"
done
find build-aux -type f \! \( \
    -name ax_progvar.m4 -o \
    -name ax_subst_man_date.m4 -o \
    -name ax_subst_transformed_package_name.m4 \
    \) -delete
ln -s %{_datadir}/gnulib/build-aux/git-version-gen build-aux/git-version-gen
echo > include/getopt-shim.h

%build
autoreconf -vfi
%configure \
    --disable-arch-native \
    --with-pic \
    --with-pthread \
    --enable-shared \
    --disable-static \
    --disable-static-exe
%{make_build}

%check
make check roundtrip %{?_smp_mflags}

%install
%{make_install}
find %{buildroot} -name '*.la' -delete
if cmp %{buildroot}%{_mandir}/man1/{bz3cat,bunzip3}.1; then
    rm %{buildroot}%{_mandir}/man1/bunzip3.1
    ln -s bz3cat.1 %{buildroot}%{_mandir}/man1/bunzip3.1
fi

%files
%define programs \{bunzip3,bz3cat,bz3grep,bz3less,bz3more,bz3most,bzip3\}
%{_bindir}/%{programs}
%{_mandir}/man1/%{programs}.1*

%files libs
%license libsais-LICENSE LICENSE
%doc NEWS README.md
%{_libdir}/libbzip3.so.0{,.*}

%files devel
%{_includedir}/libbz3.h
%{_libdir}/libbzip3.so
%{_libdir}/pkgconfig/bzip3.pc

%changelog
* Fri Aug 09 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.4.0-1
- initial build
